@@ -13,7 +13,7 @@ from typedpy.structures import (
     FinalStructure,
     ImmutableField,
     unique,
-    ABCStructure
+    AbstractStructure
 )
 
 from typedpy.structures_reuse import (
